#!/usr/bin/env bash
###
 # Entry point for running unittests.
 ##


# Ensure script location is consistent, regardless of terminal calling location.
cd "$( cd "$( dirname "${BASH_SOURCE[0]}" )" >/dev/null 2>&1 && pwd )"


# Variables.
text_reset="\033[0m"
text_purple="\033[0;35m"


# Get sudo password now so we don't have to later.
echo "To fully test some functions, script may ask for your sudo password."
echo "Press enter to continue or ctrl+C to cancel."
read
sudo ls > /dev/null 2>&1


# Run Arg/Kwarg handling tests.
echo ""
echo -e "Running ${text_purple}Arg/Kwarg Handling${text_reset} tests."
bats ./test_args_kwargs.sh
echo -e "Finished ${text_purple}Arg/Kwarg Handling${text_reset} Tests."
echo ""


# Run Directory Function tests.
echo ""
echo -e "Running ${text_purple}Directory Function${text_reset} tests."
bats ./test_directory_functions.sh
echo -e "Finished ${text_purple}Directory Function${text_reset} Tests."
echo ""


# Run User Function tests.
echo ""
echo -e "Running ${text_purple}User Function${text_reset} tests."
bats ./test_user_functions.sh
sudo bats ./test_user_functions_sudo.sh
echo -e "Finished ${text_purple}User Function${text_reset} tests."
echo ""


# Run Text Function tests.
echo ""
echo -e "Running ${text_purple}Text Function${text_reset} tests."
bats ./test_text_functions.sh
echo -e "Finished ${text_purple}Text Function${text_reset} tests."
echo ""


###
 # Seems unable to run.
 # Need to figure out a way to provide fake user input as piping seems to break bats.
 ##
# Run Display Function tests.
echo ""
echo -e "Running ${text_purple}Display Function${text_reset} tests."
bats ./test_display_functions.sh
echo -e "Finished ${text_purple}Display Function${text_reset} tests."
echo ""
